#
# spec file for package python-rarfile
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-rarfile
Version:        3.0
Release:        lp150.2.3
Summary:        RAR Archive Reader for Python
License:        ISC
Group:          Development/Languages/Python
Url:            https://rarfile.readthedocs.org/
Source0:        https://pypi.io/packages/source/r/rarfile/rarfile-%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  python3-Sphinx >= 1.3
Requires:       bsdtar
Recommends:     unrar
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch
%python_subpackages

%description
This is a Python module for RAR archive reading. It supports both RAR
2.x and 3.x archives, multi volume archives, Unicode filenames,
password-protected archives, archive and file comments. The archive
parsing and non-compressed files are handled in pure Python code, for
compressed files, the "unrar" utility is run.

%package doc
Summary:        RAR Archive Reader for Python (Documentation)
Group:          Documentation/HTML
BuildArch:      noarch

%description doc
Python module for RAR archive reading.

This package contains technical documentation.

%prep
%setup -q -n rarfile-%{version}

%build
%python_build
make %{?_smp_mflags} -C doc html
rm doc/_build/html/.buildinfo
sed -i 's/\r$//' doc/_build/html/objects.inv

%install
%python_install
%python_expand %fdupes -s %{buildroot}%{$python_sitelib}

%files %{python_files}
%defattr(-,root,root,-)
%doc LICENSE
%pycache_only %{python_sitelib}/__pycache__/rarfile.*.py*
%{python_sitelib}/rarfile.py*
%{python_sitelib}/rarfile-%{version}-py%{python_version}.egg-info

%files %{python_files doc}
%defattr(-,root,root,-)
%doc LICENSE doc/_build/html/

%changelog
* Wed Mar 29 2017 aloisio@gmx.com
- Converted to single-spec
- Improved description
* Fri Feb  3 2017 aloisio@gmx.com
- Update to version 3.0
  New feature:
  * Support RAR5 archive format.  It is actually completely
    different archive format from RAR3 one, only is uses same
    file extension and tools are old one.
    Except incompatibilies noted below, most of code should
    notice no change, existing :class:`RarInfo` fields will
    continue using RAR3-compatible values
    (eg. :attr:`RarInfo.host_os`).  RAR5-specific values
    will use new fields.
  Incompatibilities between rarfile v2.x and 3.x:
  * Default :data:`PATH_SEP` is now '/' instead '\\'.
  * Removed :data:`NEED_COMMENTS` option, comments are always
    extracted.
  * Removed :data:`UNICODE_COMMENTS` option, they are always
    decoded.
  * Removed :data:`USE_DATETIME` option,
    :attr:`RarInfo.date_time` is always tuple,
    :attr:`RarInfo.mtime`, :attr:`RarInfo.atime`,
    :attr:`RarInfo.ctime` and
    :attr:`RarInfo.arctime` are always
    :class:`datetime.datetime` objects.
  Fixes:
  * Fixed bug when calling rarfp.open() on a RarInfo structure.
  Cleanups:
  * Code refactor to allow 2 different file format parsers.
  * Code cleanups to pass modern linters.
  * New testing and linting setup based on Tox_.
  * Use setuptools instead distutils for install.
- Changed source URL to pypi.io
* Mon Sep 12 2016 aloisio@gmx.com
- Update to version 2.8
  * Fix: support solid archives from in-memory file object.
    Full archive will be written out to temp file. [#21]
  * Fix: ask unrar stop switches scanning, to handle archive
    names starting with "-". (Alexander Shadchin) [#12]
  * Fix: add missing _parse_error variable to RarFile object.
    (Gregory Mazzola) [#20]
  * Fix: return proper boolean from
    :meth:`RarInfo.needs_password`. [#22]
  * Fix: do not insert non-string rarfile into exception
    string. (Tim Muller) [#23]
  * Fix: make :meth:`RarFile.extract` and
    :meth:`RarFile.testrar` support in-memory archives.
  * Use cryptography module as preferred crypto backend.
    PyCrypto will be used as fallback.
  * Cleanup: remove compat code for Python 2.4/2.5/2.6.
- Switched to bsdtar and made unrar dependency optional
- Changed source URL
* Mon Apr 25 2016 aloisio@gmx.com
- Update to version 2.7
  * Allow use of bsdtar as decompression backend.
    It sits on top of libarchive, which has support for reading
    RAR archives.
  * Now rarfile checks if unrar and if not then tries bsdtar. If
    that works, then keeps using it. If not then configuration
    stays with unrar which will then appear in error messages.
  * Both RarFile and is_rarfile() now accept file-like object.
    Eg. io.BytesIO. Only requirement is that the object must be
    seekable. This mirrors similar funtionality in zipfile.
  * Uniform error handling. RarFile accepts errors="strict" argument.
  * Allow user to tune whether parsing and missing file errors
    will raise exception. If error is not raised, the error
    string can be queried with RarFile.strerror() method.
* Mon Jul 13 2015 toddrme2178@gmail.com
- Fix building on SLES 11
* Fri Aug 15 2014 toddrme2178@gmail.com
- Spec file cleanups
* Thu Apr 11 2013 lazy.kent@opensuse.org
- Update to 2.6.
  * Add context manager support for RarFile class. Both RarFile and
    RarExtFile support with statement now.
  * RarFile.volumelist() method, returns filenames of archive
    volumes.
  * Re-throw clearer error in case unrar is not found in PATH.
  * Sync new unrar4.x error code from rar.txt.
  * Use Sphinx for documentation.
- Build doc subpackage.
* Sun Apr 29 2012 lazy.kent@opensuse.org
- Removed check for unsupported openSUSE versions.
- Corrected Description.
* Thu Jan 19 2012 lazy.kent@opensuse.org
- Update to 2.5.
  * Fixed bugs.
* Fri Nov 11 2011 lazy.kent@opensuse.org
- Update to 2.4.
  * Fix bug in corrupt unicode filename handling.
- Use full URL as a source.
* Thu Nov 10 2011 lazy.kent@opensuse.org
- Initial package created - 2.3.
